polyfemos.back.seismic.edlogreader — polyfemos 0.3.29 documentation

# polyfemos.back.seismic.edlogreader

Reads Earth Data LOG files

Includes `get_data()` function for extracting data from Earth Data LOG files

Extracts 1 datapoint per day (this is everthing that is available). Other state of health parameters are available as MSEED files containing continuous data.

Parameters available using `get_data()` `key` in parentheses

- latitude (lat)

- longitude (long)

- date (date), a string containing year, month and day

- time (time), a string containing hour, minute and second

- heading (hdng) *

- magnetic variation (mva) *

- velocity (vel) *

- 16 bit phase error in 1 second pll (plle) **

* Are these important? Do they contain any useful information?
** Also available as MSEED so better to use that

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.back.seismic.edlogreader.` `get_data`(path='', key='', scale=<function <lambda>>)
  Parameters

    - path (str) – filename of the Earth Data LOG file

    - key (str) – A value to be extracted

  Return type

    float or None

  Returns

    A single float value read from ED log file, If somenthing went wrong (e.g. the path was invalid), return `None`.

Private Functions

`polyfemos.back.seismic.edlogreader.` `_ed_log_get_value_from_rows`(rows, key)

  Searches for `key` in rows If the `key` is found, returns the value to the ‘right’ of the key

  Parameters

    - rows (list) – list of lists of strings

    - key (str) –

  Return type

    None, str

  Returns

    Value corresponding to the key or `None` if the key is not found in `rows`

`polyfemos.back.seismic.edlogreader.` `_ed_log_parse_row`(row)

  Converts a (binary) string `row` to list

  Parameters

    row (str) – (binary) string

  Return type

    list

  Returns

    A modified `row`

`polyfemos.back.seismic.edlogreader.` `_ed_log_replacer`(str_)

  The function is used to replace some string in the Earth Data LOG file to their respective `key` names

  Parameters

    str_ (str) –

  Return type

    str

  Returns

    A string with some values replaced

`polyfemos.back.seismic.edlogreader.` `_ed_log_valid_row`(row)

  Used to filter out rows which does not contain desired information

  Parameters

    row (list) –

  Return type

    bool

  Returns